Advice class final

Generated advice about this change, used for providing more information about how a change will affect the existing service.

Constructors

Advice({String description = ''})
Advice.fromJson(Object? j)
factory

Properties

description → String
Useful description for why this advice was applied and what actions should be taken to mitigate any implied risks.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String