AuthProvider class final

Configuration for an authentication provider, including support for JSON Web Token (JWT).

Constructors

AuthProvider({String id = '', String issuer = '', String jwksUri = '', String audiences = '', String authorizationUrl = '', List<JwtLocation> jwtLocations = const []})
AuthProvider.fromJson(Object? j)
factory

Properties

audiences → String
The list of JWT audiences. that are allowed to access. A JWT containing any of these audiences will be accepted. When this setting is absent, JWTs with audiences:
final
authorizationUrl → String
Redirect URL if JWT token is required but not present or is expired. Implement authorizationUrl of securityDefinitions in OpenAPI spec.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the auth provider. It will be referred to by AuthRequirement.provider_id.
final
issuer → String
Identifies the principal that issued the JWT. See https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.1 Usually a URL or an email address.
final
jwksUri → String
URL of the provider's public key set to validate signature of the JWT. See OpenID Discovery. Optional if the key set document:
final
jwtLocations → List<JwtLocation>
Defines the locations to extract the JWT. For now it is only used by the Cloud Endpoints to store the OpenAPI extension x-google-jwt-locations (https://cloud.google.com/endpoints/docs/openapi/openapi-extensions#x-google-jwt-locations)
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String