AuthRequirement class final

User-defined authentication requirements, including support for JSON Web Token (JWT).

Constructors

AuthRequirement({String providerId = '', String audiences = ''})
AuthRequirement.fromJson(Object? j)
factory

Properties

audiences → String
NOTE: This will be deprecated soon, once AuthProvider.audiences is implemented and accepted in all the runtime components.
final
hashCode → int
The hash code for this object.
no setterinherited
providerId → String
id from authentication provider.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String