AuthenticationRule class final

Authentication rules for the service.

By default, if a method has any authentication requirements, every request must include a valid credential matching one of the requirements. It's an error to include more than one kind of credential in a single request.

If a method doesn't have any auth requirements, request credentials will be ignored.

Constructors

AuthenticationRule({String selector = '', OauthRequirements? oauth, bool allowWithoutCredential = false, List<AuthRequirement> requirements = const []})
AuthenticationRule.fromJson(Object? j)
factory

Properties

allowWithoutCredential → bool
If true, the service accepts API keys without any other credential. This flag only applies to HTTP and gRPC requests.
final
hashCode → int
The hash code for this object.
no setterinherited
oauth → OauthRequirements?
The requirements for OAuth credentials.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requirements → List<AuthRequirement>
Requirements for additional authentication providers.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → String
Selects the methods to which this rule applies.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String