discriminatorFields property

List<String> discriminatorFields
final

A list of the fields in the request message. Two requests will be batched together only if the values of every field specified in request_discriminator_fields is equal between the two requests.

Implementation

final List<String> discriminatorFields;