subresponseField property

String subresponseField
final

Optional. When present, indicates the field in the response message to be used to demultiplex the response into multiple response messages, in correspondence with the multiple request messages originally batched together.

Implementation

final String subresponseField;