delayThreshold property

Duration? delayThreshold
final

The duration after which a batch should be sent, starting from the addition of the first message to that batch.

Implementation

final Duration? delayThreshold;