elementCountLimit property
The maximum number of elements collected in a batch that could be accepted by server.
Implementation
final int elementCountLimit;
The maximum number of elements collected in a batch that could be accepted by server.
final int elementCountLimit;