requestByteThreshold property

int requestByteThreshold
final

The aggregated size of the batched field which, if exceeded, causes the batch to be sent. This size is computed by aggregating the sizes of the request field to be batched, not of the entire request message.

Implementation

final int requestByteThreshold;