Billing class final

Billing related configuration of the service.

The following example shows how to configure monitored resources and metrics for billing, consumer_destinations is the only supported destination and the monitored resources need at least one label key cloud.googleapis.com/location to indicate the location of the billing usage, using different monitored resources between monitoring and billing is recommended so they can be evolved independently:

monitored_resources:
- type: library.googleapis.com/billing_branch
  labels:
  - key: cloud.googleapis.com/location
    description: |
      Predefined label to support billing location restriction.
  - key: city
    description: |
      Custom label to define the city where the library branch is located
      in.
  - key: name
    description: Custom label to define the name of the library branch.
metrics:
- name: library.googleapis.com/book/borrowed_count
  metric_kind: DELTA
  value_type: INT64
  unit: "1"
billing:
  consumer_destinations:
  - monitored_resource: library.googleapis.com/billing_branch
    metrics:
    - library.googleapis.com/book/borrowed_count

Constructors

Billing({List<Billing_BillingDestination> consumerDestinations = const []})
Billing.fromJson(Object? j)
factory

Properties

consumerDestinations → List<Billing_BillingDestination>
Billing configurations for sending metrics to the consumer project. There can be multiple consumer destinations per service, each one must have a different monitored resource type. A metric can be used in at most one consumer destination.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String