Billing_BillingDestination class final

Configuration of a specific billing destination (Currently only support bill against consumer project).

Constructors

Billing_BillingDestination({String monitoredResource = '', List<String> metrics = const []})
Billing_BillingDestination.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metrics → List<String>
Names of the metrics to report to this billing destination. Each name must be defined in Service.metrics section.
final
monitoredResource → String
The monitored resource type. The type must be defined in Service.monitored_resources section.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String