ChangeType class final

Classifies set of possible modifications to an object in the service configuration.

Constructors

ChangeType(String value)
const
ChangeType.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const ChangeType
The default value for ChangeType.
added → const ChangeType
The changed object exists in the 'new' service configuration, but not in the 'old' service configuration.
changeTypeUnspecified → const ChangeType
No value was provided.
modified → const ChangeType
The changed object exists in both service configurations, but its value is different.
removed → const ChangeType
The changed object exists in the 'old' service configuration, but not in the 'new' service configuration.