ClientLibraryDestination class final

To where should client libraries be published?

Constructors

ClientLibraryDestination(String value)
const
ClientLibraryDestination.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ClientLibraryDestination
The default value for ClientLibraryDestination.
clientLibraryDestinationUnspecified → const ClientLibraryDestination
Client libraries will neither be generated nor published to package managers.
github → const ClientLibraryDestination
Generate the client library in a repo under github.com/googleapis, but don't publish it to package managers.
packageManager → const ClientLibraryDestination
Publish the library to package managers like nuget.org and npmjs.com.