ClientLibrarySettings class final

Details about how and where to publish client libraries.

Constructors

ClientLibrarySettings({String version = '', LaunchStage launchStage = LaunchStage.$default, bool restNumericEnums = false, JavaSettings? javaSettings, CppSettings? cppSettings, PhpSettings? phpSettings, PythonSettings? pythonSettings, NodeSettings? nodeSettings, DotnetSettings? dotnetSettings, RubySettings? rubySettings, GoSettings? goSettings})
ClientLibrarySettings.fromJson(Object? j)
factory

Properties

cppSettings → CppSettings?
Settings for C++ client libraries.
final
dotnetSettings → DotnetSettings?
Settings for .NET client libraries.
final
goSettings → GoSettings?
Settings for Go client libraries.
final
hashCode → int
The hash code for this object.
no setterinherited
javaSettings → JavaSettings?
Settings for legacy Java features, supported in the Service YAML.
final
launchStage → LaunchStage
Launch stage of this version of the API.
final
nodeSettings → NodeSettings?
Settings for Node client libraries.
final
phpSettings → PhpSettings?
Settings for PHP client libraries.
final
pythonSettings → PythonSettings?
Settings for Python client libraries.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
restNumericEnums → bool
When using transport=rest, the client request will encode enums as numbers rather than strings.
final
rubySettings → RubySettings?
Settings for Ruby client libraries.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud.speech.v1" and "google.spanner.admin.database.v1".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String