CommonLanguageSettings class final

Required information for every language.

Constructors

CommonLanguageSettings({String referenceDocsUri = '', List<ClientLibraryDestination> destinations = const [], SelectiveGapicGeneration? selectiveGapicGeneration})
CommonLanguageSettings.fromJson(Object? j)
factory

Properties

destinations → List<ClientLibraryDestination>
The destination where API teams want this client library to be published.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
referenceDocsUri → String
Link to automatically generated reference documentation. Example: https://cloud.google.com/nodejs/docs/reference/asset/latest
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectiveGapicGeneration → SelectiveGapicGeneration?
Configuration for which RPCs should be generated in the GAPIC client.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String