selectiveGapicGeneration property
Configuration for which RPCs should be generated in the GAPIC client.
Note: This field should not be used in most cases.
Implementation
final SelectiveGapicGeneration? selectiveGapicGeneration;
Configuration for which RPCs should be generated in the GAPIC client.
Note: This field should not be used in most cases.
final SelectiveGapicGeneration? selectiveGapicGeneration;