ContextRule class final

A context rule provides information about the context for an individual API element.

Constructors

ContextRule({String selector = '', List<String> requested = const [], List<String> provided = const [], List<String> allowedRequestExtensions = const [], List<String> allowedResponseExtensions = const []})
ContextRule.fromJson(Object? j)
factory

Properties

allowedRequestExtensions → List<String>
A list of full type names or extension IDs of extensions allowed in grpc side channel from client to backend.
final
allowedResponseExtensions → List<String>
A list of full type names or extension IDs of extensions allowed in grpc side channel from backend to client.
final
hashCode → int
The hash code for this object.
no setterinherited
provided → List<String>
A list of full type names of provided contexts. It is used to support propagating HTTP headers and ETags from the response extension.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requested → List<String>
A list of full type names of requested contexts, only the requested context will be made available to the backend.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → String
Selects the methods to which this rule applies.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String