Control class final

Selects and configures the service controller used by the service.

Example:

control:
  environment: servicecontrol.googleapis.com

Constructors

Control({String environment = '', List<MethodPolicy> methodPolicies = const []})
Control.fromJson(Object? j)
factory

Properties

environment → String
The service controller environment to use. If empty, no control plane features (like quota and billing) will be enabled. The recommended value for most services is servicecontrol.googleapis.com.
final
hashCode → int
The hash code for this object.
no setterinherited
methodPolicies → List<MethodPolicy>
Defines policies applying to the API methods of the service.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String