CustomHttpPattern class final

A custom pattern is used for defining custom HTTP verb.

Constructors

CustomHttpPattern({String kind = '', String path = ''})
CustomHttpPattern.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → String
The name of this custom HTTP verb.
final
path → String
The path matched by this custom verb.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String