Distribution_BucketOptions_Exponential class final

Specifies an exponential sequence of buckets that have a width that is proportional to the value of the lower bound. Each bucket represents a constant relative uncertainty on a specific value in the bucket.

There are num_finite_buckets + 2 (= N) buckets. Bucket i has the following boundaries:

Upper bound (0 <= i < N-1): scale * (growth_factor ^ i).

Lower bound (1 <= i < N): scale * (growth_factor ^ (i - 1)).

Constructors

Distribution_BucketOptions_Exponential({int numFiniteBuckets = 0, double growthFactor = 0, double scale = 0})
Distribution_BucketOptions_Exponential.fromJson(Object? j)
factory

Properties

growthFactor → double
Must be greater than 1.
final
hashCode → int
The hash code for this object.
no setterinherited
numFiniteBuckets → int
Must be greater than 0.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
Must be greater than 0.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String