Distribution_BucketOptions_Linear class final

Specifies a linear sequence of buckets that all have the same width (except overflow and underflow). Each bucket represents a constant absolute uncertainty on the specific value in the bucket.

There are num_finite_buckets + 2 (= N) buckets. Bucket i has the following boundaries:

Upper bound (0 <= i < N-1): offset + (width * i).

Lower bound (1 <= i < N): offset + (width * (i - 1)).

Constructors

Distribution_BucketOptions_Linear({int numFiniteBuckets = 0, double width = 0, double offset = 0})
Distribution_BucketOptions_Linear.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
numFiniteBuckets → int
Must be greater than 0.
final
offset → double
Lower bound of the first bucket.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
Must be greater than 0.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String