Distribution_Range class final

The range of the population values.

Constructors

Distribution_Range({double min = 0, double max = 0})
Distribution_Range.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → double
The maximum of the population values.
final
min → double
The minimum of the population values.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String