DocumentationRule class final

A documentation rule provides information about individual API elements.

Constructors

DocumentationRule({String selector = '', String description = '', String deprecationDescription = ''})
DocumentationRule.fromJson(Object? j)
factory

Properties

deprecationDescription → String
Deprecation description of the selected element(s). It can be provided if an element is marked as deprecated.
final
description → String
Description of the selected proto element (e.g. a message, a method, a 'service' definition, or a field). Defaults to leading & trailing comments taken from the proto source definition of the proto element.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → String
The selector is a comma-separated list of patterns for any element such as a method, a field, an enum value. Each pattern is a qualified name of the element which may end in "", indicating a wildcard. Wildcards are only allowed at the end and for a whole component of the qualified name, i.e. "foo." is ok, but not "foo.b*" or "foo..bar". A wildcard will match one or more components. To specify a default for all applicable elements, the whole pattern "" is used.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String