DotnetSettings class final

Settings for Dotnet client libraries.

Constructors

DotnetSettings({CommonLanguageSettings? common, Map<String, String> renamedServices = const {}, Map<String, String> renamedResources = const {}, List<String> ignoredResources = const [], List<String> forcedNamespaceAliases = const [], List<String> handwrittenSignatures = const []})
DotnetSettings.fromJson(Object? j)
factory

Properties

common → CommonLanguageSettings?
Some settings.
final
forcedNamespaceAliases → List<String>
Namespaces which must be aliased in snippets due to a known (but non-generator-predictable) naming collision
final
handwrittenSignatures → List<String>
Method signatures (in the form "service.method(signature)") which are provided separately, so shouldn't be generated. Snippets calling these methods are still generated, however.
final
hashCode → int
The hash code for this object.
no setterinherited
ignoredResources → List<String>
List of full resource types to ignore during generation. This is typically used for API-specific Location resources, which should be handled by the generator as if they were actually the common Location resources. Example entry: "documentai.googleapis.com/Location"
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
renamedResources → Map<String, String>
Map from full resource types to the effective short name for the resource. This is used when otherwise resource named from different services would cause naming collisions. Example entry: "datalabeling.googleapis.com/Dataset": "DataLabelingDataset"
final
renamedServices → Map<String, String>
Map from original service names to renamed versions. This is used when the default generated types would cause a naming conflict. (Neither name is fully-qualified.) Example: Subscriber to SubscriberServiceApi.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String