FieldInfo class final

Rich semantic information of an API field beyond basic typing.

Constructors

FieldInfo({FieldInfo_Format format = FieldInfo_Format.$default, List<TypeReference> referencedTypes = const []})
FieldInfo.fromJson(Object? j)
factory

Properties

format → FieldInfo_Format
The standard format of a field value. This does not explicitly configure any API consumer, just documents the API's format for the field it is applied to.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
referencedTypes → List<TypeReference>
The type(s) that the annotated, generic field may represent.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String