FlowControlLimitExceededBehaviorProto class final

The behavior to take when the flow control limit is exceeded.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const FlowControlLimitExceededBehaviorProto
The default value for FlowControlLimitExceededBehaviorProto.
block → const FlowControlLimitExceededBehaviorProto
Pause operation until limit clears.
ignore → const FlowControlLimitExceededBehaviorProto
Continue operation, disregard limit.
throwException → const FlowControlLimitExceededBehaviorProto
Stop operation, raise error.
unsetBehavior → const FlowControlLimitExceededBehaviorProto
Default behavior, system-defined.