LabelDescriptor class final

A description of a label.

Constructors

LabelDescriptor({String key = '', LabelDescriptor_ValueType valueType = LabelDescriptor_ValueType.$default, String description = ''})
LabelDescriptor.fromJson(Object? j)
factory

Properties

description → String
A human-readable description for the label.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String
The label key.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueType → LabelDescriptor_ValueType
The type of data that can be assigned to the label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String