LogDescriptor class final

A description of a log type. Example in YAML format:

- name: library.googleapis.com/activity_history
  description: The history of borrowing and returning library items.
  display_name: Activity
  labels:
  - key: /customer_id
    description: Identifier of a library customer

Constructors

LogDescriptor({String name = '', List<LabelDescriptor> labels = const [], String description = '', String displayName = ''})
LogDescriptor.fromJson(Object? j)
factory

Properties

description → String
A human-readable description of this log. This information appears in the documentation and can contain details.
final
displayName → String
The human-readable name for this log. This information appears on the user interface and should be concise.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → List<LabelDescriptor>
The set of labels that are available to describe a specific log entry. Runtime requests that contain labels not specified here are considered invalid.
final
name → String
The name of the log. It must be less than 512 characters long and can include the following characters: upper- and lower-case alphanumeric characters A-Za-z0-9, and punctuation characters including slash, underscore, hyphen, period /_-..
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String