MethodSettings class final

Describes the generator configuration for a method.

Constructors

MethodSettings({String selector = '', MethodSettings_LongRunning? longRunning, List<String> autoPopulatedFields = const [], BatchingConfigProto? batching})
MethodSettings.fromJson(Object? j)
factory

Properties

autoPopulatedFields → List<String>
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4.
final
batching → BatchingConfigProto?
Batching configuration for an API method in client libraries.
final
hashCode → int
The hash code for this object.
no setterinherited
longRunning → MethodSettings_LongRunning?
Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → String
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String