Metric class final

A specific metric, identified by specifying values for all of the labels of a google.api.MetricDescriptor.

Constructors

Metric({String type = '', Map<String, String> labels = const {}})
Metric.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
The set of label values that uniquely identify this metric. All labels listed in the MetricDescriptor must be assigned values.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
An existing metric type, see google.api.MetricDescriptor. For example, custom.googleapis.com/invoice/paid/amount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String