MetricDescriptor_MetricKind class final
The kind of measurement. It describes how the data is reported.
For information on setting the start time and end time based on
the MetricKind, see TimeInterval.
Constructors
- MetricDescriptor_MetricKind(String value)
-
const
- MetricDescriptor_MetricKind.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const MetricDescriptor_MetricKind
- The default value for MetricDescriptor_MetricKind.
- cumulative → const MetricDescriptor_MetricKind
- A value accumulated over a time interval. Cumulative measurements in a time series should have the same start time and increasing end times, until an event resets the cumulative value to zero and sets a new start time for the following points.
- delta → const MetricDescriptor_MetricKind
- The change in a value during a time interval.
- gauge → const MetricDescriptor_MetricKind
- An instantaneous measurement of a value.
- metricKindUnspecified → const MetricDescriptor_MetricKind
- Do not use this default value.