MetricRule class final

Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.

Constructors

MetricRule({String selector = '', Map<String, int> metricCosts = const {}})
MetricRule.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricCosts → Map<String, int>
Metrics to update when the selected methods are called, and the associated cost applied to each metric.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → String
Selects the methods to which this rule applies.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String