PythonSettings_ExperimentalFeatures class final

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default.

Constructors

PythonSettings_ExperimentalFeatures({bool restAsyncIoEnabled = false, bool protobufPythonicTypesEnabled = false, bool unversionedPackageDisabled = false})
PythonSettings_ExperimentalFeatures.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
protobufPythonicTypesEnabled → bool
Enables generation of protobuf code using new types that are more Pythonic which are included in protobuf>=5.29.x. This feature will be enabled by default 1 month after launching the feature in preview packages.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
restAsyncIoEnabled → bool
Enables generation of asynchronous REST clients if rest transport is enabled. By default, asynchronous REST clients will not be generated. This feature will be enabled by default 1 month after launching the feature in preview packages.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unversionedPackageDisabled → bool
Disables generation of an unversioned Python package for this client library. This means that the module names will need to be versioned in import statements. For example import google.cloud.library_v2 instead of import google.cloud.library.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String