ResourceDescriptor_History class final

A description of the historical or future-looking state of the resource pattern.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const ResourceDescriptor_History
The default value for ResourceDescriptor_History.
futureMultiPattern → const ResourceDescriptor_History
The resource has one pattern, but the API owner expects to add more later. (This is the inverse of ORIGINALLY_SINGLE_PATTERN, and prevents that from being necessary once there are multiple patterns.)
historyUnspecified → const ResourceDescriptor_History
The "unset" value.
originallySinglePattern → const ResourceDescriptor_History
The resource originally had one pattern and launched as such, and additional patterns were added later.