SelectiveGapicGeneration class final

This message is used to configure the generation of a subset of the RPCs in a service for client libraries.

Note: This feature should not be used in most cases.

Constructors

SelectiveGapicGeneration({List<String> methods = const [], bool generateOmittedAsInternal = false})
SelectiveGapicGeneration.fromJson(Object? j)
factory

Properties

generateOmittedAsInternal → bool
Setting this to true indicates to the client generators that methods that would be excluded from the generation should instead be generated in a way that indicates these methods should not be consumed by end users. How this is expressed is up to individual language implementations to decide. Some examples may be: added annotations, obfuscated identifiers, or other language idiomatic patterns.
final
hashCode → int
The hash code for this object.
no setterinherited
methods → List<String>
An allowlist of the fully qualified names of RPCs that should be included on public client surfaces.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String