SystemParameter class final

Define a parameter's name and location. The parameter may be passed as either an HTTP header or a URL query parameter, and if both are passed the behavior is implementation-dependent.

Constructors

SystemParameter({String name = '', String httpHeader = '', String urlQueryParameter = ''})
SystemParameter.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpHeader → String
Define the HTTP header name to use for the parameter. It is case insensitive.
final
name → String
Define the name of the parameter, such as "api_key" . It is case sensitive.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlQueryParameter → String
Define the URL query parameter name to use for the parameter. It is case sensitive.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String