SystemParameterRule class final

Define a system parameter rule mapping system parameter definitions to methods.

Constructors

SystemParameterRule({String selector = '', List<SystemParameter> parameters = const []})
SystemParameterRule.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameters → List<SystemParameter>
Define parameters. Multiple names may be defined for a parameter. For a given method call, only one of them should be used. If multiple names are used the behavior is implementation-dependent. If none of the specified names are present the behavior is parameter-dependent.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → String
Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String