UsageRule class final

Usage configuration rules for the service.

Constructors

UsageRule({String selector = '', bool allowUnregisteredCalls = false, bool skipServiceControl = false})
UsageRule.fromJson(Object? j)
factory

Properties

allowUnregisteredCalls bool
Use this rule to configure unregistered calls for the service. Unregistered calls are calls that do not contain consumer project identity. (Example: calls that do not contain an API key).
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selector String
Selects the methods to which this rule applies. Use '*' to indicate all methods in all APIs.
final
skipServiceControl bool
If true, the selected method should skip service control and the control plane features, such as quota and billing, will not be available. This flag is used by Google Cloud Endpoints to bypass checks for internal methods, such as service health check methods.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String