allowUnregisteredCalls property

bool allowUnregisteredCalls
final

Use this rule to configure unregistered calls for the service. Unregistered calls are calls that do not contain consumer project identity. (Example: calls that do not contain an API key).

WARNING: By default, API methods do not allow unregistered calls, and each method call must be identified by a consumer project identity.

Implementation

final bool allowUnregisteredCalls;