pathTranslation property
Path translation specifies how to combine the backend address with the
request path in order to produce the appropriate forwarding URL for the
request. See PathTranslation for
more details.
Implementation
final BackendRule_PathTranslation pathTranslation;