BatchingConfigProto class final
BatchingConfigProto defines the batching configuration for an API method.
Constructors
- BatchingConfigProto({BatchingSettingsProto? thresholds, BatchingDescriptorProto? batchDescriptor})
- BatchingConfigProto.fromJson(Object? j)
-
factory
Properties
- batchDescriptor → BatchingDescriptorProto?
-
The request and response fields used in batching.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thresholds → BatchingSettingsProto?
-
The thresholds which trigger a batched request to be sent.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String