BatchingDescriptorProto class final
BatchingDescriptorProto specifies the fields of the request message to be
used for batching, and, optionally, the fields of the response message to be
used for demultiplexing.
Constructors
-
BatchingDescriptorProto({String batchedField = '', List<
String> discriminatorFields = const [], String subresponseField = ''}) - BatchingDescriptorProto.fromJson(Object? j)
-
factory
Properties
- batchedField → String
-
The repeated field in the request message to be aggregated by batching.
final
-
discriminatorFields
→ List<
String> -
A list of the fields in the request message. Two requests will be batched
together only if the values of every field specified in
request_discriminator_fieldsis equal between the two requests.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subresponseField → String
-
Optional. When present, indicates the field in the response message to be
used to demultiplex the response into multiple response messages, in
correspondence with the multiple request messages originally batched
together.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String