BatchingSettingsProto class final

BatchingSettingsProto specifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request. At least one threshold must be positive nonzero.

Constructors

BatchingSettingsProto({int elementCountThreshold = 0, int requestByteThreshold = 0, Duration? delayThreshold, int elementCountLimit = 0, int requestByteLimit = 0, int flowControlElementLimit = 0, int flowControlByteLimit = 0, FlowControlLimitExceededBehaviorProto flowControlLimitExceededBehavior = FlowControlLimitExceededBehaviorProto.$default})
BatchingSettingsProto.fromJson(Object? j)
factory

Properties

delayThreshold → Duration?
The duration after which a batch should be sent, starting from the addition of the first message to that batch.
final
elementCountLimit int
The maximum number of elements collected in a batch that could be accepted by server.
final
elementCountThreshold int
The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.
final
flowControlByteLimit int
The maximum size of data allowed by flow control.
final
flowControlElementLimit int
The maximum number of elements allowed by flow control.
final
flowControlLimitExceededBehavior FlowControlLimitExceededBehaviorProto
The behavior to take when the flow control limit is exceeded.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestByteLimit int
The maximum size of the request that could be accepted by server.
final
requestByteThreshold int
The aggregated size of the batched field which, if exceeded, causes the batch to be sent. This size is computed by aggregating the sizes of the request field to be batched, not of the entire request message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String