elementCountThreshold property
The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.
Implementation
final int elementCountThreshold;
The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.
final int elementCountThreshold;