ClientLibraryOrganization class final

The organization for which the client libraries are being published. Affects the url where generated docs are published, etc.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const ClientLibraryOrganization
The default value for ClientLibraryOrganization.
ads → const ClientLibraryOrganization
Ads (Advertising) Org.
clientLibraryOrganizationUnspecified → const ClientLibraryOrganization
Not useful.
cloud → const ClientLibraryOrganization
Google Cloud Platform Org.
generativeAi → const ClientLibraryOrganization
Generative AI - https://developers.generativeai.google
geo → const ClientLibraryOrganization
Geo Org.
photos → const ClientLibraryOrganization
Photos Org.
shopping → const ClientLibraryOrganization
Shopping Org.
streetView → const ClientLibraryOrganization
Street View Org.