credentialAndroidAppInvalid constant
ErrorReason
const credentialAndroidAppInvalid
The request is denied because the associated application credential header is invalid for an Android applications.
Example of an ErrorInfo when the request from an Android application to the "pubsub.googleapis.com" with an invalid application credential header.
{
"reason": "CREDENTIAL_ANDROID_APP_INVALID",
"domain": "googleapis.com",
"metadata": {
"service": "pubsub.googleapis.com"
}
}
Implementation
static const credentialAndroidAppInvalid = ErrorReason(
'CREDENTIAL_ANDROID_APP_INVALID',
);