locationOrgPolicyViolated constant
ErrorReason
const locationOrgPolicyViolated
The request whose associated location violates the location org policy restrictions when creating resources in the restricted region.
Example of an ErrorInfo when creating the Cloud Storage Bucket in the container "projects/123" under a restricted region "locations/asia-northeast3":
{
"reason": "LOCATION_ORG_POLICY_VIOLATED",
"domain": "googleapis.com",
"metadata": {
"resource": "projects/123",
"location": "locations/asia-northeast3"
}
}
This response indicates creating the Cloud Storage Bucket in "locations/asia-northeast3" violates the location org policy restriction.
Implementation
static const locationOrgPolicyViolated = ErrorReason(
'LOCATION_ORG_POLICY_VIOLATED',
);