autoPopulatedFields property

List<String> autoPopulatedFields
final

List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4.

Example of a YAML configuration:

publishing:
  method_settings:
  - selector: google.example.v1.ExampleService.CreateExample
    auto_populated_fields:
    - request_id

Implementation

final List<String> autoPopulatedFields;