selector property
The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
Example:
publishing:
method_settings:
- selector: google.storage.control.v2.StorageControl.CreateFolder
# method settings for CreateFolder...
Implementation
final String selector;